@@ -16,6 +16,15 @@
 
 
 import utils.files.file as file
+import utils.files.file_read as read
+import utils.files.file_write as write
+import utils.files.file_image as image
+import utils.files.file_convert as convert
+import utils.files.file_compression as compress
+
+
+
+
 
 decompress = file.decompress
 compress = file.compress
