@@ -23,7 +23,8 @@ import logging
 
 import ftputil
 from ftputil.error import FTPOSError
-import colemen_string_utils as strUtils
+# import colemen_string_utils as strUtils
+import facades.string_facade as strUtils
 import utils.files.file as file
 import utils.object_utils as obj
 import utils.files.file_write as write
@@ -258,10 +259,10 @@ def get_folders(search_path=False, **kwargs):
                 dir_data['file_path'] = os.path.join(root, current_dir)
                 ignore = False
                 if len(exclude) > 0:
-                    if strUtils.parse.array_in_string(exclude, dir_data['file_path']) is True:
+                    if strUtils.mod.array_in_string(exclude, dir_data['file_path']) is True:
                         continue
                 if len(include) > 0:
-                    if strUtils.parse.array_in_string(include, dir_data['file_path']) is False:
+                    if strUtils.mod.array_in_string(include, dir_data['file_path']) is False:
                         continue
                 # if ignore_array is not False:
                 #     for x in ignore_array:
@@ -369,10 +370,10 @@ def get_folders_ftp(search_path=False, **kwargs):
                 dir_data['file_path'] = os.path.join(root, current_dir)
                 ignore = False
                 if len(exclude) > 0:
-                    if strUtils.parse.array_in_string(exclude, dir_data['file_path']) is True:
+                    if strUtils.mod.array_in_string(exclude, dir_data['file_path']) is True:
                         continue
                 if len(include) > 0:
-                    if strUtils.parse.array_in_string(include, dir_data['file_path']) is False:
+                    if strUtils.mod.array_in_string(include, dir_data['file_path']) is False:
                         continue
 
                 dir_array.append(dir_data)
